# Generated by Django 4.1.7 on 2023-03-03 23:16

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('oasis', '0009_associatebalance'),
    ]

    operations = [
        migrations.CreateModel(
            name='Operation',
            fields=[
                ('companyid', models.IntegerField(db_column='companyid', primary_key=True, serialize=False)),
                ('documentid', models.CharField(max_length=3)),
                ('numberid', models.IntegerField()),
                ('locationid', models.IntegerField(db_column='locationid')),
                ('date', models.DateField(blank=True, db_column='"Date"', null=True)),
                ('hour', models.DateField(blank=True, null=True)),
                ('clientid', models.BigIntegerField(blank=True, null=True)),
                ('directionid', models.IntegerField(blank=True, null=True)),
                ('vendorid', models.BigIntegerField(blank=True, null=True)),
                ('conceptid', models.CharField(blank=True, max_length=3, null=True)),
                ('motiveid', models.IntegerField(blank=True, null=True)),
                ('conditionpaymentid', models.IntegerField(blank=True, null=True)),
                ('typepriceid', models.IntegerField(blank=True, null=True)),
                ('discountpercentage', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('discountpercentage2', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('promptpaymentid', models.IntegerField(blank=True, null=True)),
                ('promptpayment', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('pricetax', models.CharField(blank=True, max_length=1, null=True)),
                ('quantity', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('weight', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('volume', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('brute', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('discount', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('subtotal', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('tax', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('taxsale', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('imco', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('total', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('retention', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('retentiontaxsale', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('retentionica', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('retentioncre', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('net', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('payment', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('change', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('paid', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('totalcost', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('totalsupplier', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('adjustment', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('documentid1', models.CharField(blank=True, max_length=3, null=True)),
                ('numberid1', models.IntegerField(blank=True, null=True)),
                ('numberid2', models.IntegerField(blank=True, null=True)),
                ('numberid3', models.IntegerField(blank=True, null=True)),
                ('cashid', models.IntegerField(blank=True, null=True)),
                ('warehouseid', models.IntegerField(blank=True, null=True)),
                ('invstate', models.BooleanField(blank=True, null=True)),
                ('inventory', models.BooleanField(blank=True, null=True)),
                ('destinylocationid', models.IntegerField(blank=True, null=True)),
                ('box', models.IntegerField(blank=True, null=True)),
                ('formpaymentid', models.IntegerField(blank=True, null=True)),
                ('confirmdate', models.DateField(blank=True, null=True)),
                ('confirmhour', models.DateField(blank=True, null=True)),
                ('printdate', models.DateField(blank=True, null=True)),
                ('printhour', models.DateField(blank=True, null=True)),
                ('prefix', models.CharField(blank=True, max_length=10, null=True)),
                ('currencyid', models.IntegerField(blank=True, null=True)),
                ('exchangerate', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('saledate', models.DateField(blank=True, null=True)),
                ('quota', models.BooleanField(blank=True, null=True)),
                ('bond', models.BooleanField(blank=True, null=True)),
                ('quotavalue', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('zoneid', models.IntegerField(blank=True, null=True)),
                ('origin', models.BooleanField(blank=True, null=True)),
                ('totaltranscription', models.IntegerField(blank=True, null=True)),
                ('transcription', models.IntegerField(blank=True, null=True)),
                ('bondvalue', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('bondtax', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('turnid', models.IntegerField(blank=True, null=True)),
                ('freight', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('secure', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('pointsadd', models.IntegerField(blank=True, null=True)),
                ('pointsrest', models.IntegerField(blank=True, null=True)),
                ('vehicleid', models.CharField(blank=True, max_length=10, null=True)),
                ('businessid', models.IntegerField(blank=True, null=True)),
                ('projectid', models.IntegerField(blank=True, null=True)),
                ('affiliateid', models.BigIntegerField(blank=True, null=True)),
                ('documentlocationid', models.IntegerField(blank=True, null=True)),
                ('international', models.BooleanField(blank=True, null=True)),
                ('typedocument', models.CharField(blank=True, max_length=3, null=True)),
                ('documentaffiliate', models.CharField(blank=True, max_length=20, null=True)),
                ('fiscalvoucher', models.CharField(blank=True, max_length=100, null=True)),
                ('billerid', models.BigIntegerField(blank=True, null=True)),
                ('recipe', models.IntegerField(blank=True, null=True)),
                ('formuladate', models.DateField(blank=True, null=True)),
                ('freightnumber', models.IntegerField(blank=True, null=True)),
                ('freightcost', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('routeid', models.IntegerField(blank=True, null=True)),
                ('transporterid', models.BigIntegerField(blank=True, null=True)),
                ('timedelivery', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('printedletter', models.BooleanField(blank=True, null=True)),
                ('statewms', models.CharField(blank=True, max_length=1, null=True)),
                ('numberidpre', models.IntegerField(blank=True, null=True)),
                ('locationidpre', models.IntegerField(blank=True, null=True)),
                ('turnsale', models.IntegerField(blank=True, null=True)),
                ('island', models.IntegerField(blank=True, null=True)),
                ('repetitive', models.BooleanField(blank=True, null=True)),
                ('periods', models.IntegerField(blank=True, null=True)),
                ('executed', models.IntegerField(blank=True, null=True)),
                ('quotacopayment', models.BooleanField(blank=True, null=True)),
                ('tariff', models.CharField(blank=True, max_length=1, null=True)),
                ('copaymentpercentage', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('quotacopaymentdiscriminate', models.BooleanField(blank=True, null=True)),
                ('diagnosticid', models.CharField(blank=True, max_length=9, null=True)),
                ('doctorid', models.BigIntegerField(blank=True, db_column='doctorid', null=True)),
                ('passyear', models.BooleanField(blank=True, null=True)),
                ('changeyear', models.BooleanField(blank=True, null=True)),
                ('synchronized', models.BooleanField(blank=True, null=True)),
                ('codeaccumulate', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('reference1', models.CharField(blank=True, max_length=50, null=True)),
                ('reference2', models.CharField(blank=True, max_length=50, null=True)),
                ('domicile', models.BooleanField(blank=True, null=True)),
                ('responsibleid', models.BigIntegerField(blank=True, null=True)),
                ('quotationid', models.IntegerField(blank=True, null=True)),
                ('orderid', models.IntegerField(blank=True, null=True)),
                ('contractid', models.IntegerField(blank=True, null=True)),
                ('contractlocationid', models.IntegerField(blank=True, null=True)),
                ('invoiceid', models.IntegerField(blank=True, null=True)),
                ('locationuseid', models.IntegerField(blank=True, null=True)),
                ('initialdate', models.DateField(blank=True, null=True)),
                ('finaldate', models.DateField(blank=True, null=True)),
                ('plancontract', models.IntegerField(blank=True, null=True)),
                ('policy', models.CharField(blank=True, max_length=10, null=True)),
                ('copayment', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('commission', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('receipt', models.IntegerField(blank=True, null=True)),
                ('highcost', models.BooleanField(blank=True, null=True)),
                ('health', models.BooleanField(blank=True, null=True)),
                ('contractcapited', models.IntegerField(blank=True, null=True)),
                ('sinister', models.IntegerField(blank=True, null=True)),
                ('invoicedate', models.DateField(blank=True, null=True)),
                ('retainpayment', models.BooleanField(blank=True, null=True)),
                ('invoicechar', models.CharField(blank=True, max_length=15, null=True)),
                ('checknumber', models.IntegerField(blank=True, null=True)),
                ('fund', models.IntegerField(blank=True, null=True)),
                ('doclocationid', models.IntegerField(blank=True, null=True)),
                ('retentionif', models.BooleanField(blank=True, null=True)),
                ('reconciled', models.BooleanField(blank=True, null=True)),
                ('reconcileddate', models.DateField(blank=True, null=True)),
                ('anticipation', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('anticipationnumberid', models.IntegerField(blank=True, null=True)),
                ('basepromptpayment', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('pricegenerate', models.BooleanField(blank=True, null=True)),
                ('typeliquidation', models.CharField(blank=True, max_length=1, null=True)),
                ('expensevalue', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('agreement', models.IntegerField(blank=True, null=True)),
                ('agreementlocationid', models.IntegerField(blank=True, null=True)),
                ('provenance', models.CharField(blank=True, max_length=80, null=True)),
                ('program', models.IntegerField(blank=True, null=True)),
                ('basekilo', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('check_operation', models.BooleanField(blank=True, db_column='"Check"', null=True)),
                ('weightbrute', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('destare', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('weightnet', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('amortize', models.IntegerField(blank=True, null=True)),
                ('seal', models.IntegerField(blank=True, null=True)),
                ('reference', models.CharField(blank=True, max_length=20, null=True)),
                ('credit', models.CharField(blank=True, max_length=1, null=True)),
                ('packing', models.BooleanField(blank=True, null=True)),
                ('lotid', models.CharField(blank=True, max_length=20, null=True)),
                ('documentexpense', models.IntegerField(blank=True, null=True)),
                ('costcenterid', models.IntegerField(blank=True, null=True)),
                ('received', models.BooleanField(blank=True, null=True)),
                ('backorder', models.BooleanField(blank=True, null=True)),
                ('translationdirect', models.BooleanField(blank=True, null=True)),
                ('deliverydate', models.DateField(blank=True, null=True)),
                ('payfreight', models.BooleanField(blank=True, null=True)),
                ('deliverydatemax', models.DateField(blank=True, null=True)),
                ('priority', models.IntegerField(blank=True, null=True)),
                ('consolidated', models.BooleanField(blank=True, null=True)),
                ('dispatch', models.BooleanField(blank=True, null=True)),
                ('dispatchpercentage', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('dispatchvalue', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('separatevalue', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('separate', models.BooleanField(blank=True, null=True)),
                ('liberation', models.BigIntegerField(blank=True, null=True)),
                ('commercial', models.CharField(blank=True, max_length=1, null=True)),
                ('liberationcommercial', models.BigIntegerField(blank=True, null=True)),
                ('sfa', models.BooleanField(blank=True, null=True)),
                ('consignment', models.BooleanField(blank=True, null=True)),
                ('billingdate', models.DateField(blank=True, null=True)),
                ('fattenig', models.BooleanField(blank=True, null=True)),
                ('picking', models.BooleanField(blank=True, null=True)),
                ('edi', models.BooleanField(blank=True, null=True)),
                ('surety', models.BooleanField(blank=True, null=True)),
                ('suretyexecute', models.BooleanField(blank=True, null=True)),
                ('suretyvalue', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('prorogation', models.DateField(blank=True, null=True)),
                ('daysdelivery', models.IntegerField(blank=True, null=True)),
                ('daysdeliverychar', models.CharField(blank=True, max_length=100, null=True)),
                ('transact', models.DateField(blank=True, null=True)),
                ('budgeting', models.BooleanField(blank=True, null=True)),
                ('entryid', models.BigIntegerField(blank=True, null=True)),
                ('devolutiondate', models.DateField(blank=True, null=True)),
                ('typedelivery', models.CharField(blank=True, max_length=1, null=True)),
                ('bankid', models.IntegerField(blank=True, null=True)),
                ('lettercredit', models.CharField(blank=True, max_length=20, null=True)),
                ('estimated', models.BooleanField(blank=True, null=True)),
                ('verbalacceptance', models.BooleanField(blank=True, null=True)),
                ('authorizeexpense', models.BigIntegerField(blank=True, null=True)),
                ('surveyorid', models.BigIntegerField(blank=True, null=True)),
                ('approves', models.BooleanField(blank=True, null=True)),
                ('accumulate', models.BooleanField(blank=True, null=True)),
                ('approbationdate', models.DateField(blank=True, null=True)),
                ('approbacionby', models.BigIntegerField(blank=True, null=True)),
                ('themeid', models.IntegerField(blank=True, null=True)),
                ('formstart', models.IntegerField(blank=True, null=True)),
                ('applicantid', models.BigIntegerField(blank=True, null=True)),
                ('userid', models.IntegerField(blank=True, null=True)),
                ('incoterms', models.CharField(blank=True, max_length=3, null=True)),
                ('employeeid', models.BigIntegerField(blank=True, null=True)),
                ('guarantee', models.DateField(blank=True, null=True)),
                ('representativeid', models.BigIntegerField(blank=True, null=True)),
                ('purchaseorder', models.CharField(blank=True, max_length=20, null=True)),
                ('periodtype', models.CharField(blank=True, max_length=1, null=True)),
                ('duration', models.IntegerField(blank=True, null=True)),
                ('template', models.IntegerField(blank=True, null=True)),
                ('upc', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('upcpercentage', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('upcaffiliate', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('costadministration', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('sanction', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('otherif', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('coverage', models.CharField(blank=True, max_length=100, null=True)),
                ('assurerid', models.BigIntegerField(blank=True, null=True)),
                ('assured', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('validitypolicy', models.DateField(blank=True, null=True)),
                ('delivery', models.DateField(blank=True, null=True)),
                ('lastinvoice', models.DateField(blank=True, null=True)),
                ('nextinvoice', models.DateField(blank=True, null=True)),
                ('validatesaffiliate', models.BooleanField(blank=True, null=True)),
                ('typecontract', models.CharField(blank=True, max_length=1, null=True)),
                ('cyclebilling', models.CharField(blank=True, max_length=1, null=True)),
                ('renovation', models.CharField(blank=True, max_length=1, null=True)),
                ('increment', models.CharField(blank=True, db_column='"Increment"', max_length=1, null=True)),
                ('incrementvalue', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('renews', models.CharField(blank=True, max_length=1, null=True)),
                ('currency', models.CharField(blank=True, max_length=1, null=True)),
                ('formalitycontract', models.CharField(blank=True, max_length=1, null=True)),
                ('affiliates', models.IntegerField(blank=True, null=True)),
                ('tariffupc', models.IntegerField(blank=True, null=True)),
                ('requirement', models.BigIntegerField(blank=True, null=True)),
                ('forminitiation', models.IntegerField(blank=True, null=True)),
                ('expenseresponsibleid', models.BigIntegerField(blank=True, null=True)),
                ('subscription', models.DateField(blank=True, null=True)),
                ('printed', models.BooleanField(blank=True, null=True)),
                ('mark', models.BooleanField(blank=True, null=True)),
                ('status', models.CharField(blank=True, max_length=1, null=True)),
                ('state', models.CharField(blank=True, max_length=1, null=True)),
                ('updated', models.DateField(blank=True, null=True)),
                ('locationid1', models.IntegerField(blank=True, null=True)),
                ('contactid', models.BigIntegerField(blank=True, null=True)),
                ('typecontractid', models.IntegerField(blank=True, null=True)),
                ('typetransportid', models.IntegerField(blank=True, null=True)),
                ('countryoriginid', models.IntegerField(blank=True, null=True)),
                ('expiration', models.DateField(blank=True, null=True)),
                ('numbercontract', models.IntegerField(blank=True, null=True)),
                ('locationidcontract', models.IntegerField(blank=True, null=True)),
                ('classificationid', models.BigIntegerField(blank=True, null=True)),
                ('type', models.CharField(blank=True, max_length=1, null=True)),
                ('attention', models.BooleanField(blank=True, null=True)),
                ('responsableid', models.BigIntegerField(blank=True, null=True)),
                ('providerid', models.BigIntegerField(blank=True, null=True)),
                ('diagnostic', models.CharField(blank=True, max_length=9, null=True)),
                ('diagnostic1', models.CharField(blank=True, max_length=9, null=True)),
                ('diagnostic2', models.CharField(blank=True, max_length=9, null=True)),
                ('diagnostic3', models.CharField(blank=True, max_length=9, null=True)),
                ('impute', models.CharField(blank=True, max_length=1, null=True)),
                ('valueimpute', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('class_field', models.CharField(blank=True, db_column='class', max_length=1, null=True)),
                ('programid', models.IntegerField(blank=True, null=True)),
                ('typesolicitude', models.CharField(blank=True, max_length=1, null=True)),
                ('locationsolicitude', models.CharField(blank=True, max_length=1, null=True)),
                ('servicesolicitude', models.CharField(blank=True, max_length=40, null=True)),
                ('numbersolicitude', models.IntegerField(blank=True, null=True)),
                ('datesolicitude', models.DateField(blank=True, null=True)),
                ('hoursolicitude', models.DateField(blank=True, null=True)),
                ('dateacttutelage', models.DateField(blank=True, null=True)),
                ('authorizationmanual', models.BigIntegerField(blank=True, null=True)),
                ('copaymentmanual', models.IntegerField(blank=True, null=True)),
                ('justificationid', models.IntegerField(blank=True, null=True)),
                ('alternatetiveid1', models.IntegerField(blank=True, null=True)),
                ('alternatetiveid2', models.IntegerField(blank=True, null=True)),
                ('alternatetiveid3', models.IntegerField(blank=True, null=True)),
                ('alternatetiveid4', models.IntegerField(blank=True, null=True)),
                ('modalitycon', models.CharField(blank=True, max_length=2, null=True)),
                ('sinisterid', models.IntegerField(blank=True, null=True)),
                ('typeorigin', models.CharField(blank=True, max_length=1, null=True)),
                ('typepriority', models.CharField(blank=True, max_length=1, null=True)),
                ('formpost', models.CharField(blank=True, max_length=1, null=True)),
                ('shipping', models.DateField(blank=True, null=True)),
                ('shippingentity', models.DateField(blank=True, null=True)),
                ('bill', models.CharField(blank=True, max_length=17, null=True)),
                ('web', models.CharField(blank=True, max_length=1, null=True)),
                ('stateaffiliate', models.CharField(blank=True, max_length=2, null=True)),
                ('typedoctorid', models.IntegerField(blank=True, null=True)),
                ('contractgloss', models.IntegerField(blank=True, null=True)),
                ('typeaffdoctorid', models.IntegerField(blank=True, null=True)),
                ('docdoctor', models.BigIntegerField(blank=True, null=True)),
                ('typedocumentiddoctor', models.CharField(blank=True, max_length=2, null=True)),
                ('statebdua', models.CharField(blank=True, max_length=2, null=True)),
                ('levelsisben', models.IntegerField(blank=True, null=True)),
                ('numbersolicitudeoasis', models.BigIntegerField(blank=True, null=True)),
                ('anticipate', models.BooleanField(blank=True, null=True)),
                ('dateorder', models.DateField(blank=True, null=True)),
                ('filingorder', models.DateField(blank=True, null=True)),
                ('regimen', models.CharField(blank=True, max_length=1, null=True)),
                ('levelcontributory', models.IntegerField(blank=True, null=True)),
                ('concurrence', models.BooleanField(blank=True, null=True)),
                ('filing', models.DateField(blank=True, null=True)),
                ('locationprovider', models.IntegerField(blank=True, null=True)),
                ('confirmby', models.BigIntegerField(blank=True, null=True)),
                ('age', models.CharField(blank=True, max_length=30, null=True)),
                ('dateprovision', models.DateField(blank=True, null=True)),
                ('valuebill', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('geographiclocationid', models.IntegerField(blank=True, null=True)),
                ('ingress', models.DateField(blank=True, null=True)),
                ('originattention', models.CharField(blank=True, max_length=1, null=True)),
                ('typeservice', models.CharField(blank=True, max_length=1, null=True)),
                ('priorityattention', models.CharField(blank=True, max_length=1, null=True)),
                ('typelocationaffiliate', models.CharField(blank=True, max_length=1, null=True)),
                ('codeservice', models.IntegerField(blank=True, null=True)),
                ('subspeciality', models.IntegerField(blank=True, null=True)),
                ('numberbed', models.CharField(blank=True, max_length=20, null=True)),
                ('justificationclinic', models.CharField(blank=True, max_length=1000, null=True)),
                ('documentapplicantid', models.BigIntegerField(blank=True, null=True)),
                ('nameapplicantid', models.CharField(blank=True, max_length=200, null=True)),
                ('phone', models.CharField(blank=True, max_length=100, null=True)),
                ('placeactivity', models.CharField(blank=True, max_length=500, null=True)),
                ('source', models.CharField(blank=True, max_length=1, null=True)),
                ('motive', models.CharField(blank=True, max_length=1000, null=True)),
                ('typeuser', models.CharField(blank=True, max_length=1, null=True)),
                ('notification', models.DateField(blank=True, null=True)),
                ('automatic', models.BooleanField(blank=True, null=True)),
                ('doctor', models.CharField(blank=True, max_length=100, null=True)),
                ('placedoctor', models.CharField(blank=True, max_length=100, null=True)),
                ('motiveannulationid', models.IntegerField(blank=True, null=True)),
                ('sonof', models.BooleanField(blank=True, null=True)),
                ('year', models.IntegerField(blank=True, null=True)),
                ('filed', models.DateField(blank=True, null=True)),
                ('record', models.CharField(blank=True, max_length=20, null=True)),
                ('history', models.CharField(blank=True, max_length=20, null=True)),
                ('ambit', models.CharField(blank=True, max_length=1, null=True)),
                ('objective', models.CharField(blank=True, max_length=1, null=True)),
                ('negation', models.IntegerField(blank=True, null=True)),
                ('locationnegation', models.IntegerField(blank=True, null=True)),
                ('specialidadid', models.IntegerField(blank=True, null=True)),
                ('letterentity', models.BooleanField(blank=True, null=True)),
                ('alfanet', models.BigIntegerField(blank=True, null=True)),
                ('datealfanet', models.DateField(blank=True, null=True)),
                ('datemeeting', models.DateField(blank=True, null=True)),
                ('presolicitude', models.IntegerField(blank=True, null=True)),
                ('locationpresolicitude', models.IntegerField(blank=True, null=True)),
                ('clientideps', models.BigIntegerField(blank=True, null=True)),
                ('clientidips', models.BigIntegerField(blank=True, null=True)),
                ('clientiduser', models.BigIntegerField(blank=True, null=True)),
                ('accepted', models.BooleanField(blank=True, null=True)),
                ('docdocumentid', models.IntegerField(blank=True, null=True)),
                ('meeting', models.IntegerField(blank=True, null=True)),
                ('assessorid', models.BigIntegerField(blank=True, null=True)),
                ('clientidsolicitude', models.BigIntegerField(blank=True, null=True)),
                ('ambitsolicitude', models.CharField(blank=True, max_length=1, null=True)),
                ('numberapprobation', models.IntegerField(blank=True, null=True)),
                ('recovery', models.CharField(blank=True, max_length=20, null=True)),
                ('actioning', models.CharField(blank=True, max_length=100, null=True)),
                ('actioned', models.CharField(blank=True, max_length=1, null=True)),
                ('impugn', models.CharField(blank=True, max_length=1, null=True)),
                ('judgedid', models.IntegerField(blank=True, null=True)),
                ('file', models.IntegerField(blank=True, db_column='"File"', null=True)),
                ('judgement', models.DateField(blank=True, null=True)),
                ('integral', models.BooleanField(blank=True, null=True)),
                ('ctc', models.BooleanField(blank=True, null=True)),
                ('pretensionid', models.IntegerField(blank=True, null=True)),
                ('typedocumentidactioning', models.CharField(blank=True, max_length=2, null=True)),
                ('docactioning', models.CharField(blank=True, max_length=20, null=True)),
                ('nameactioning', models.CharField(blank=True, max_length=100, null=True)),
                ('revoked', models.BooleanField(blank=True, null=True)),
                ('provisional', models.BooleanField(blank=True, null=True)),
                ('deliverysuccessive', models.BooleanField(blank=True, null=True)),
                ('pos', models.BooleanField(blank=True, null=True)),
                ('days', models.IntegerField(blank=True, null=True)),
                ('docnegation', models.CharField(blank=True, max_length=2, null=True)),
                ('dateauto', models.DateField(blank=True, null=True)),
                ('numberjudgement', models.BigIntegerField(blank=True, null=True)),
                ('datesinister', models.DateField(blank=True, null=True)),
                ('policyid', models.IntegerField(blank=True, null=True)),
                ('aviso', models.BooleanField(blank=True, null=True)),
                ('dateaviso', models.DateField(blank=True, null=True)),
                ('numberaviso', models.IntegerField(blank=True, null=True)),
                ('bills', models.IntegerField(blank=True, null=True)),
                ('stateevent', models.CharField(blank=True, max_length=2, null=True)),
                ('deductible', models.BooleanField(blank=True, null=True)),
                ('gloss', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('notapplicable', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('glosssure', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('recovered', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('valuedeductible', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('recover', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('datereport', models.DateField(blank=True, null=True)),
                ('datebirth', models.DateField(blank=True, null=True)),
                ('viaingress', models.CharField(blank=True, max_length=1, null=True)),
                ('houringress', models.DateField(blank=True, null=True)),
                ('parturitioncaesarean', models.BooleanField(blank=True, null=True)),
                ('documentbill', models.CharField(blank=True, max_length=3, null=True)),
                ('numberbill', models.IntegerField(blank=True, null=True)),
                ('locationbill', models.IntegerField(blank=True, null=True)),
                ('quantitydays', models.IntegerField(blank=True, null=True)),
                ('egress', models.DateField(blank=True, null=True)),
                ('typedocumentidresponsable', models.CharField(blank=True, max_length=2, null=True)),
                ('documentidresponsable', models.CharField(blank=True, max_length=20, null=True)),
                ('nameresponsable', models.CharField(blank=True, max_length=200, null=True)),
                ('addressresponsable', models.CharField(blank=True, max_length=100, null=True)),
                ('phoneresponsable', models.CharField(blank=True, max_length=30, null=True)),
                ('geolocationidresponsable', models.IntegerField(blank=True, null=True)),
                ('nameprofessional', models.CharField(blank=True, max_length=20, null=True)),
                ('cellularprofessional', models.CharField(blank=True, max_length=20, null=True)),
                ('phoneprofessional', models.CharField(blank=True, max_length=20, null=True)),
                ('serviceorigin', models.BigIntegerField(blank=True, null=True)),
                ('servicesolicited', models.BigIntegerField(blank=True, null=True)),
                ('typeambulance', models.CharField(blank=True, max_length=1, null=True)),
                ('typetranslation', models.CharField(blank=True, max_length=1, null=True)),
                ('dateambulance', models.DateField(blank=True, null=True)),
                ('dateclose', models.DateField(blank=True, null=True)),
                ('hourclose', models.DateField(blank=True, null=True)),
                ('numberattention', models.IntegerField(blank=True, null=True)),
                ('triage', models.CharField(blank=True, max_length=1, null=True)),
                ('remission', models.BooleanField(blank=True, null=True)),
                ('nameips', models.CharField(blank=True, max_length=60, null=True)),
                ('codehabipsremission', models.CharField(blank=True, max_length=12, null=True)),
                ('locationipsremission', models.IntegerField(blank=True, null=True)),
                ('destination', models.CharField(blank=True, max_length=2, null=True)),
                ('nameinformant', models.CharField(blank=True, max_length=40, null=True)),
                ('placeinformant', models.CharField(blank=True, max_length=50, null=True)),
                ('phoneinformant', models.CharField(blank=True, max_length=30, null=True)),
                ('cellularinformant', models.CharField(blank=True, max_length=30, null=True)),
                ('registerby', models.BigIntegerField(blank=True, null=True)),
                ('nameregister', models.CharField(blank=True, max_length=40, null=True)),
                ('docnumberid', models.BigIntegerField(blank=True, null=True)),
                ('markpre', models.CharField(blank=True, max_length=1, null=True)),
                ('analysis', models.CharField(blank=True, max_length=4000, null=True)),
                ('approbation', models.CharField(blank=True, max_length=4000, null=True)),
                ('description', models.CharField(blank=True, max_length=4000, null=True)),
                ('justification', models.CharField(blank=True, max_length=4000, null=True)),
                ('observation', models.CharField(blank=True, max_length=4000, null=True)),
                ('resume', models.CharField(blank=True, max_length=4000, null=True)),
                ('textapplicant', models.CharField(blank=True, max_length=4000, null=True)),
                ('textapprobation', models.CharField(blank=True, max_length=4000, null=True)),
                ('formula', models.CharField(blank=True, max_length=20, null=True)),
                ('remissioninvoice', models.CharField(blank=True, max_length=1, null=True)),
                ('typedocumentid', models.CharField(blank=True, max_length=2, null=True)),
                ('clientcode', models.CharField(blank=True, max_length=20, null=True)),
                ('firstlastname', models.CharField(blank=True, max_length=40, null=True)),
                ('secondlastname', models.CharField(blank=True, max_length=30, null=True)),
                ('firstfirstname', models.CharField(blank=True, max_length=40, null=True)),
                ('secondfirstname', models.CharField(blank=True, max_length=30, null=True)),
                ('birthdate', models.DateField(blank=True, null=True)),
                ('finaldate1', models.DateField(blank=True, null=True)),
                ('upcaffiliate1', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('affiliates1', models.IntegerField(blank=True, null=True)),
                ('total1', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('bl', models.CharField(blank=True, max_length=50, null=True)),
                ('containers', models.IntegerField(blank=True, null=True)),
                ('countrydestinyid', models.IntegerField(blank=True, null=True)),
                ('countrypurchaseid', models.IntegerField(blank=True, null=True)),
                ('countryshipmentid', models.IntegerField(blank=True, null=True)),
                ('customsid', models.IntegerField(blank=True, null=True)),
                ('datearrival', models.DateField(blank=True, null=True)),
                ('datebl', models.DateField(blank=True, null=True)),
                ('incotermsid', models.CharField(blank=True, max_length=3, null=True)),
                ('lines', models.IntegerField(blank=True, null=True)),
                ('packages', models.IntegerField(blank=True, null=True)),
                ('portdestiny', models.CharField(blank=True, max_length=50, null=True)),
                ('portshipment', models.CharField(blank=True, max_length=50, null=True)),
                ('vessel', models.CharField(blank=True, max_length=50, null=True)),
                ('equipmentid', models.CharField(blank=True, max_length=20, null=True)),
                ('conductorid', models.BigIntegerField(blank=True, null=True)),
                ('assistantid', models.BigIntegerField(blank=True, null=True)),
                ('guide', models.BigIntegerField(blank=True, null=True)),
                ('weighttare', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('weightloaded', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('counterinitial', models.IntegerField(blank=True, null=True)),
                ('counterfinal', models.IntegerField(blank=True, null=True)),
                ('counter', models.IntegerField(blank=True, null=True)),
                ('stop', models.BooleanField(blank=True, null=True)),
                ('failureid', models.IntegerField(blank=True, null=True)),
                ('causeid', models.IntegerField(blank=True, null=True)),
                ('actionid', models.IntegerField(blank=True, null=True)),
                ('subject', models.CharField(blank=True, max_length=4000, null=True)),
                ('time', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('daterequired', models.DateField(blank=True, null=True)),
                ('hourrequired', models.DateField(blank=True, null=True)),
                ('billto', models.CharField(blank=True, max_length=1, null=True)),
                ('qualification', models.CharField(blank=True, max_length=1, null=True)),
                ('typeoperationid', models.IntegerField(blank=True, null=True)),
                ('lineid', models.IntegerField(blank=True, null=True)),
                ('initialhour', models.DateField(blank=True, null=True)),
                ('finalhour', models.DateField(blank=True, null=True)),
                ('turn', models.IntegerField(blank=True, null=True)),
                ('packingwms', models.BooleanField(blank=True, null=True)),
                ('contractdocumentid', models.CharField(blank=True, max_length=3, null=True)),
                ('priority1', models.IntegerField(blank=True, null=True)),
                ('sourceid', models.IntegerField(blank=True, null=True)),
                ('dateincapacity', models.DateField(blank=True, null=True)),
                ('dateparturition', models.DateField(blank=True, null=True)),
                ('parturitionmultiple', models.BooleanField(blank=True, null=True)),
                ('weeks', models.IntegerField(blank=True, null=True)),
                ('dateaccident', models.DateField(blank=True, null=True)),
                ('isprorogation', models.BooleanField(blank=True, null=True)),
                ('overlap', models.BooleanField(blank=True, null=True)),
                ('hospitalization', models.BooleanField(blank=True, null=True)),
                ('requirements', models.BooleanField(blank=True, null=True)),
                ('dayspayment', models.IntegerField(blank=True, null=True)),
                ('datepayment', models.DateField(blank=True, null=True)),
                ('sample', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('drift1', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('drift2', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('almondsan', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('gramspasilla', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('gramsbroca', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('productid', models.BigIntegerField(blank=True, null=True)),
                ('associate', models.BooleanField(blank=True, null=True)),
                ('quantity1', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('resourceid', models.BigIntegerField(blank=True, null=True)),
                ('updatedby', models.IntegerField(blank=True, null=True)),
                ('quantityslime', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('paymentid', models.BigIntegerField(blank=True, null=True)),
                ('localizationid', models.CharField(blank=True, max_length=20, null=True)),
                ('xml', models.BinaryField(blank=True, null=True)),
                ('xmlname', models.CharField(blank=True, max_length=100, null=True)),
                ('status1', models.CharField(blank=True, max_length=1, null=True)),
                ('presales', models.BigIntegerField(blank=True, null=True)),
                ('documentidbudget', models.CharField(blank=True, max_length=3, null=True)),
                ('numberidbudget', models.IntegerField(blank=True, null=True)),
                ('locationidbudget', models.IntegerField(blank=True, null=True)),
                ('budgetyearpass', models.BooleanField(blank=True, null=True)),
                ('budgetyearchanged', models.BooleanField(blank=True, null=True)),
                ('overexecuted', models.CharField(blank=True, max_length=1, null=True)),
                ('contractidfiled', models.BigIntegerField(blank=True, null=True)),
                ('docdocumentcid', models.CharField(blank=True, max_length=3, null=True)),
                ('approbationreceivablehourlocal', models.DateField(blank=True, null=True)),
                ('approbationcomercialhourlocal', models.DateField(blank=True, null=True)),
                ('productid1', models.BigIntegerField(blank=True, null=True)),
                ('productid2', models.BigIntegerField(blank=True, null=True)),
                ('productid3', models.BigIntegerField(blank=True, null=True)),
                ('emailprofessional', models.CharField(blank=True, max_length=50, null=True)),
                ('modetranslation', models.CharField(blank=True, max_length=1, null=True)),
                ('public', models.BooleanField(blank=True, db_column='"Public"', null=True)),
                ('sequestration', models.BooleanField(blank=True, null=True)),
                ('translape', models.BooleanField(blank=True, null=True)),
                ('daysprorogation', models.IntegerField(blank=True, null=True)),
                ('cashonly', models.BooleanField(blank=True, null=True)),
                ('transporterfreight', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('license', models.IntegerField(blank=True, null=True)),
                ('cdp', models.IntegerField(blank=True, null=True)),
                ('planningweek', models.IntegerField(blank=True, null=True)),
            ],
            options={
                'db_table': 'operation',
                'managed': False,
            },
        ),
    ]



# -*- coding: utf-8 -*-

#  Developed by CQ Inversiones SAS. Copyright ©. 2019 - 2023. All rights reserved.
#  Desarrollado por CQ Inversiones SAS. Copyright ©. 2019 - 2023. Todos los derechos reservado

# ****************************************************************
# IDE:          PyCharm
# Developed by: macercha
# Date:         26/02/23 16:03
# Project:      CFHL Transactional Backend
# Module Name:  date_validators
# Description:
# ****************************************************************
from datetime import datetime
from django.core.exceptions import ValidationError
from django.utils.translation import gettext_lazy as _


def eq_greater_than_today(value: datetime) -> None:
    now_datetime = datetime.now()
    now_date = datetime(now_datetime.year, now_datetime.month, now_datetime.day)
    source_date = datetime(value.year, value.month, value.day)

    if source_date < now_date:
        raise ValidationError(_("Received date is less than current date"))


def greater_than_today(value: datetime) -> None:
    now_datetime = datetime.now()
    now_date = datetime(now_datetime.year, now_datetime.month, now_datetime.day)
    source_date = datetime(value.year, value.month, value.day)

    if source_date <= now_date:
        raise ValidationError(_("Received date is less than or equal to current date"))



# Generated by Django 4.1.5 on 2023-02-02 01:56

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('oasis', '0004_account_vaccountingbalanceclient'),
    ]

    operations = [
        migrations.DeleteModel(
            name='VAccountingBalanceClient',
        ),
        migrations.AddConstraint(
            model_name='company',
            constraint=models.UniqueConstraint(fields=('company_id',), name='UNQ_company_company_id'),
        ),
    ]



# Generated by Django 4.1.7 on 2023-03-07 16:27

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('oasis', '0015_statemachine_update_oasis'),
    ]

    operations = [
        migrations.AddField(
            model_name='statemachine',
            name='is_changed',
            field=models.BooleanField(default=False, verbose_name='Validate changes'),
        ),
        migrations.AddField(
            model_name='statemachine',
            name='timeout',
            field=models.IntegerField(default=0, verbose_name='Timeout (hours)'),
        ),
    ]



# Generated by Django 4.1.5 on 2023-02-07 02:05

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('oasis', '0006_periods'),
    ]

    operations = [
        migrations.CreateModel(
            name='Cycle',
            fields=[
                ('companyid', models.IntegerField(primary_key=True, serialize=False)),
                ('type', models.CharField(max_length=1)),
                ('number', models.IntegerField(db_column='"Number"')),
                ('year', models.IntegerField()),
                ('period', models.IntegerField()),
                ('periodyear', models.IntegerField()),
                ('updated', models.DateField(blank=True, null=True)),
                ('updatedby', models.IntegerField(blank=True, null=True)),
            ],
            options={
                'db_table': 'cycle',
                'managed': False,
            },
        ),
    ]



# -*- coding: utf-8 -*-

#  Developed by CQ Inversiones SAS. Copyright ©. 2019 - 2023. All rights reserved.
#  Desarrollado por CQ Inversiones SAS. Copyright ©. 2019 - 2023. Todos los derechos reservado

# ****************************************************************
# IDE:          PyCharm
# Developed by: macercha
# Date:         3/03/23 8:29
# Project:      CFHL Transactional Backend
# Module Name:  oasis_actions
# Description:
# ****************************************************************
from django.conf import settings
from django.core.exceptions import ValidationError
from django.utils.translation import gettext_lazy as _
from oasis.coffee_offers.lib.utils import OfferStateMachine
from oasis.models import Operation
from oasis.models import Offer
from typing import Any


class OasisActions:
    def __init__(self, data_cache: dict):
        if data_cache is not None and {"data", "action"} <= data_cache.keys():
            self.__data = data_cache.get("data")
            self.__action = data_cache.get("action")
            self.__user = data_cache.get("user", None)
        else:
            raise ValueError(_("Invalid initialization data."))

    def __get_method(self) -> str:
        return "_" + self.__action

    def do_action(self) -> Any:
        if hasattr(self, self.__get_method()):
            # Get the method name
            method = getattr(self, self.__get_method())
            # Invoke the method
            return method()
        else:
            raise ValidationError(_("Action does not have an associated method."))

    def _save_offer(self) -> bool:
        """
        Method associated to "save_offer" action from sign rest service
        :return:
        """
        try:
            data = self.__data
            user = self.__user

            saved = Operation.objects.operation_insert(user, data.get("product"), data.get("location"),
                                                       data.get("amount"), data.get("price"), data.get("to_date"))
        except Exception as exc:
            raise
        else:
            return True

    def _change_status(self):
        try:
            document_id = settings.COFFEE_OFFERS_DOCUMENT
            user = self.__user
            offer_id = self.__data.get("offer_id", None)
            new_state = self.__data.get("status", None)
            if offer_id is not None and new_state is not None:
                offer = Offer.objects.get_by_pk(pk=offer_id).get()
                operation = Operation.objects.get_by_operation_pk(document_id=document_id,
                                                                  location_id=offer.warehouse.location_id,
                                                                  number_id=offer.contract).first()
                if operation is not None:
                    state_machine = OfferStateMachine(offer=offer, operation=operation)
                    state_machine.set(new_state=new_state)
                else:
                    raise Operation.DoesNotExist(_("Operation record does not exist!"))
            else:
                raise ValidationError(_("Error changing state. Required data not found."))
        except Exception as exc:
            raise
        else:
            return True



# -*- coding: utf-8 -*-

#  Developed by CQ Inversiones SAS. Copyright ©. 2019 - 2023. All rights reserved.
#  Desarrollado por CQ Inversiones SAS. Copyright ©. 2019 - 2023. Todos los derechos reservado

# ****************************************************************
# IDE:          PyCharm
# Developed by: macercha
# Date:         23/02/23 10:18
# Project:      CFHL Transactional Backend
# Module Name:  coffee_ware_house
# Description:
# ****************************************************************
from oasis.models import CoffeeWareHouse
from zibanu.django.rest_framework import serializers


class CoffeeWareHouseListSerializer(serializers.ModelSerializer):

    class Meta:
        model = CoffeeWareHouse
        fields = ("location_id", "location_name")


# -*- coding: utf-8 -*-

#  Developed by CQ Inversiones SAS. Copyright ©. 2019 - 2022. All rights reserved.
#  Desarrollado por CQ Inversiones SAS. Copyright ©. 2019 - 2022. Todos los derechos reservado

# ****************************************************************
# IDE:          PyCharm
# Developed by: macercha
# Date:         10/12/22 4:48 PM
# Project:      CFHL Transactional Backend
# Module Name:  product
# Description:
# ****************************************************************
from zibanu.django.db import models


class OasisProduct(models.Manager):
    def get_queryset(self):
        return super().get_queryset().using("oasis")

    def get_products_by_classification(self, classification_id: int) -> models.QuerySet:
        queryset = self.get_queryset().filter(classificationid__exact=classification_id).values("productid", "productname", "state")
        return queryset



# -*- coding: utf-8 -*-

#  Developed by CQ Inversiones SAS. Copyright ©. 2019 - 2023. All rights reserved.
#  Desarrollado por CQ Inversiones SAS. Copyright ©. 2019 - 2023. Todos los derechos reservado

# ****************************************************************
# IDE:          PyCharm
# Developed by: macercha
# Date:         23/02/23 9:14
# Project:      CFHL Transactional Backend
# Module Name:  sync_coffee_ware_house
# Description:
# ****************************************************************
from core import celery_app
from oasis import models
from typing import Any


@celery_app.task(bind=True)
def sync_coffee_ware_house(app: Any):
    """
    Background task to sync coffe warehouse
    :param app: Any
    :return: None
    """
    location_qs = models.Location.objects.get_coffe_ware_houses()
    warehouse_model = models.CoffeeWareHouse
    for location in location_qs:
        warehouse = warehouse_model.objects.get_by_location_id(location.locationid).first()
        if warehouse is None:
            warehouse = warehouse_model()
            warehouse.location_id = location.locationid
        warehouse.location_name = location.locationname
        warehouse.save()






# -*- coding: utf-8 -*-

#  Developed by CQ Inversiones SAS. Copyright ©. 2019 - 2022. All rights reserved.
#  Desarrollado por CQ Inversiones SAS. Copyright ©. 2019 - 2022. Todos los derechos reservado

# ****************************************************************
# IDE:          PyCharm
# Developed by: macercha
# Date:         10/12/22 3:52 PM
# Project:      CFHL Transactional Backend
# Module Name:  own_models
# Description:
# ****************************************************************
from django.contrib.auth import get_user_model
from django.utils.translation import gettext_lazy as _
from oasis.coffee_offers.lib.choices import CoffeeOffersStates
from oasis.coffee_offers.lib.validators import greater_than_today
from oasis.coffee_offers.lib.validators import validate_oasis_statuses
from oasis.lib import managers
from zibanu.django.db import models


class Company(models.Model):
    """
    Model class to represent entity Company.
    """
    company_id = models.IntegerField(blank=False, null=False, verbose_name=_("Company Id"))
    name = models.CharField(max_length=100, blank=False, null=False, verbose_name=_("Company Name"))
    tax_id = models.CharField(max_length=30, blank=False, null=False, verbose_name=_("Tax Id"))
    address = models.CharField(max_length=100, blank=False, null=False, verbose_name=_("Address"))
    phone = models.CharField(max_length=100, blank=False, null=False, verbose_name=_("Phone Number"))
    city = models.CharField(max_length=100, blank=False, null=False, verbose_name=_("City"))
    legal_representative = models.CharField(max_length=150, blank=False, null=False,
                                            verbose_name=_("Legal Representative"))
    enabled = models.BooleanField(default=True, blank=False, null=False, verbose_name=_("Enabled"))
    # Set default Manager
    objects = managers.Company()

    class Meta:
        constraints = [
            models.UniqueConstraint(fields=["company_id"], name="UNQ_company_company_id")
        ]


class Product(models.Model):
    """
    Model class to represent Product entity.
    """
    product_id = models.IntegerField(blank=False, null=False, verbose_name=_("Product id"))
    name = models.CharField(max_length=250, blank=False, null=False, verbose_name=_("Product name"))
    enabled = models.BooleanField(default=True, blank=False, null=False, verbose_name=_("Is enabled"))
    # Set default manager
    objects = managers.Product()

    class Meta:
        constraints = [
            models.UniqueConstraint(fields=("product_id",), name="ownproduct_productid_unique", )
        ]


class DocumentType(models.Model):
    """
    Model class to represent DocumentType entity
    """
    type_id = models.CharField(max_length=1, blank=False, null=False, verbose_name=_("Document type oasis id"))
    description = models.CharField(max_length=50, blank=False, null=False, verbose_name=_("Document type description"))
    # Set default manager
    objects = managers.DocumentType()

    class Meta:
        constraints = [
            models.UniqueConstraint(fields=("type_id",), name="UNQ_document_type_id")
        ]


class CoffeeWareHouse(models.Model):
    """
    Model class to represent CoffeeWareHouse entity
    """
    location_id = models.IntegerField(null=False, blank=False, verbose_name=_("Location ID"))
    location_name = models.CharField(max_length=150, blank=False, null=False, verbose_name=_("Location Name"))
    # Default Manager
    objects = managers.CoffeeWareHouse()

    class Meta:
        constraints = [
            models.UniqueConstraint(fields=("location_id",), name="UNQ_coffee_ware_house_location_id")
        ]

        indexes = [
            models.Index(fields=("location_name",), name="IDX_coffee_ware_house_location")
        ]


class StateMachine(models.Model):
    state = models.IntegerField(null=False, blank=False, verbose_name=_("State"), choices=CoffeeOffersStates.choices,
                                default=CoffeeOffersStates.NEW)
    from_state = models.IntegerField(null=True, blank=True, verbose_name=_("From State"),
                                     choices=CoffeeOffersStates.choices)
    oasis_state = models.CharField(max_length=1, null=False, blank=False, verbose_name=_("Oasis State"))
    oasis_status = models.CharField(max_length=1, null=False, blank=False, verbose_name=_("Oasis Status"),
                                    validators=[validate_oasis_statuses])
    notify_user = models.BooleanField(default=True, null=False, blank=False, verbose_name=_("Notify User"))
    notify_coffee_area = models.BooleanField(default=False, null=False, blank=False,
                                             verbose_name=_("Notify Coffee Area"))
    notify_legal_area = models.BooleanField(default=False, null=False, blank=False, verbose_name=_("Notify Legal Area"))
    is_initial = models.BooleanField(default=False, null=False, blank=False, verbose_name=_("Is initial state"))
    is_final = models.BooleanField(default=False, null=False, blank=False, verbose_name=_("Is final state"))
    is_changed = models.BooleanField(default=False, null=False, blank=False, verbose_name=_("Validate changes"))
    send_contract = models.BooleanField(default=False, null=False, blank=False, verbose_name=_("Send contract"))
    update_oasis = models.BooleanField(default=False, null=False, blank=False, verbose_name=_("Update Oasis"))
    timeout = models.IntegerField(default=0, blank=False, null=False, verbose_name=_("Timeout (hours)"))
    state_at_timeout = models.IntegerField(null=True, blank=True, verbose_name=_("State at timeout"),
                                           choices=CoffeeOffersStates.choices)

    objects = managers.StateMachine()

    def __str__(self):
        return _("Status ") + self.get_state_display()

    class Meta:
        constraints = [
            models.UniqueConstraint(fields=("state", "from_state", "oasis_state", "oasis_status"),
                                    name="UNQ_CoffeeOffer_StateMachine")
        ]


class Offer(models.DatedModel):
    # Field List
    user = models.ForeignKey(get_user_model(), on_delete=models.PROTECT, related_name="offers",
                             related_query_name="user")
    contract = models.IntegerField(blank=False, null=False, verbose_name=_("Contract No"))
    warehouse = models.ForeignKey(CoffeeWareHouse, null=False, blank=False, verbose_name=_("Warehouse"),
                                  on_delete=models.PROTECT, related_query_name="warehouse")
    product = models.ForeignKey(Product, null=False, blank=False, verbose_name=_("Product"), on_delete=models.PROTECT)
    kg_offered = models.DecimalField(max_digits=9, decimal_places=2, blank=False, null=False,
                                     verbose_name=_("Kg Offered"))
    kg_received = models.DecimalField(max_digits=9, decimal_places=2, blank=False, null=False, default=0,
                                      verbose_name=_("Kg Received"))
    price = models.DecimalField(max_digits=7, decimal_places=2, blank=False, null=False, default=0,
                                verbose_name=_("Price"))
    status = models.IntegerField(choices=CoffeeOffersStates.choices, default=CoffeeOffersStates.NEW, null=False,
                                 blank=False, verbose_name=_("Status"))
    delivery_date = models.DateField(blank=False, null=False, verbose_name=_("Delivery Date"),
                                     validators=[greater_than_today])
    # Set default Manager
    objects = managers.Offer()

    @property
    def is_active(self) -> bool:
        return self.status in [CoffeeOffersStates.NEW, CoffeeOffersStates.SIGNED, CoffeeOffersStates.PARTIAL]

    class Meta:
        constraints = [
            models.UniqueConstraint(fields=("contract",), name="UNQ_Offer_Contract")
        ]

class OfferMov(models.DatedModel):
    offer = models.ForeignKey(Offer, on_delete=models.PROTECT, related_name="offer_movements", related_query_name="offer")
    status = models.IntegerField(choices=CoffeeOffersStates.choices, null=False, blank=False)
    delivery_date = models.DateField(blank=True, null=True)
    price = models.DecimalField(max_digits=7, decimal_places=2, blank=True, null=True)
    kg_offered = models.DecimalField(max_digits=9, decimal_places=2, blank=True, null=True)
    kg_received = models.DecimalField(max_digits=9, decimal_places=2, blank=True, null=True)
    created = models.BooleanField(default=False, blank=False, null=False)





# -*- coding: utf-8 -*-

#  Developed by CQ Inversiones SAS. Copyright ©. 2019 - 2023. All rights reserved.
#  Desarrollado por CQ Inversiones SAS. Copyright ©. 2019 - 2023. Todos los derechos reservado

# ****************************************************************
# IDE:          PyCharm
# Developed by: macercha
# Date:         7/02/23 3:56
# Project:      CFHL Transactional Backend
# Module Name:  oasis_cycle
# Description:
# ****************************************************************
from oasis.models import Cycle
from zibanu.django.rest_framework import serializers


class CycleSerializer(serializers.ModelSerializer):
    """
    Cycle serializer for obtain availables cycles by type
    """

    class Meta:
        model = Cycle
        fields = ("year", "cycle")


# -*- coding: utf-8 -*-

#  Developed by CQ Inversiones SAS. Copyright ©. 2019 - 2023. All rights reserved.
#  Desarrollado por CQ Inversiones SAS. Copyright ©. 2019 - 2023. Todos los derechos reservado

# ****************************************************************
# IDE:          PyCharm
# Developed by: macercha
# Date:         6/02/23 21:05
# Project:      CFHL Transactional Backend
# Module Name:  oasis_cycle
# Description:
# ****************************************************************
from django.utils.translation import gettext_lazy as _
from zibanu.django.db import models


class Cycle(models.Manager):
    def get_by_type(self, cycle_type: str) -> models.QuerySet:
        qs = self.filter(type__exact=cycle_type).order_by("year", "cycle").values("year", "cycle").distinct()
        return qs

    def get_period(self, year: int, cycle: int, cycle_type: str) -> int:
        try:
            qs = self.filter(year__exact=year, cycle__exact=cycle, type__exact=cycle_type).aggregate(period=models.Max("period"))
            period = qs.get("period")
        except self.model.DoesNotExist:
            raise self.model.DoesNotExist(_("A record for year, cycle and cycle type does not found."))
        except Exception as exc:
            raise Exception(_("Not controlled exception at 'get_period' on Cycle manager class."))
        else:
            return period




# -*- coding: utf-8 -*-

#  Developed by CQ Inversiones SAS. Copyright ©. 2019 - 2023. All rights reserved.
#  Desarrollado por CQ Inversiones SAS. Copyright ©. 2019 - 2023. Todos los derechos reservado

# ****************************************************************
# IDE:          PyCharm
# Developed by: macercha
# Date:         17/01/23 4:53 PM
# Project:      CFHL Transactional Backend
# Module Name:  type_client
# Description:
# ****************************************************************
from zibanu.django.db import models


class OasisTypeClient(models.Manager):
    def get_for_sync(self) -> models.QuerySet:
        qs = self.get_queryset().values("typeclientid", "typeclientname").all()
        return qs



# -*- coding: utf-8 -*-

#  Developed by CQ Inversiones SAS. Copyright ©. 2019 - 2022. All rights reserved.
#  Desarrollado por CQ Inversiones SAS. Copyright ©. 2019 - 2022. Todos los derechos reservado

# ****************************************************************
# IDE:          PyCharm
# Developed by: macercha
# Date:         10/12/22 4:02 PM
# Project:      CFHL Transactional Backend
# Module Name:  sync_products
# Description:
# ****************************************************************
from core import celery_app
from django.conf import settings
from django.core.exceptions import ObjectDoesNotExist
from oasis import models
from typing import Any


@celery_app.task(bind=True)
def sync_products(app: Any):
    """
    Shared task for pre_load a list of products from OASIS database
    :return: None
    """
    classification_id = settings.OASIS_COFFEE_PRODUCT_CLASSIFICATION_ID
    products = models.OasisProduct.objects.get_products_by_classification(classification_id)

    if products is not None and len(products) > 0:
        for product in products:
            own_product = models.Product()
            product_name = product.get("producname1") if product.get("producname1") is not None else product.get(
                "productname")
            try:
                own_product = models.Product.objects.get_by_product(product_id=product.get("productid"))
                own_product.name = product_name
                own_product.product_id = product.get("productid")
                own_product.is_enabled = True if product.get("state") == "A" else False
            except ObjectDoesNotExist:
                own_product = models.Product(name=product_name, product_id=product.get("productid"))
            except Exception as exc:
                print(exc)
            finally:
                own_product.save()



# -*- coding: utf-8 -*-

#  Developed by CQ Inversiones SAS. Copyright ©. 2019 - 2023. All rights reserved.
#  Desarrollado por CQ Inversiones SAS. Copyright ©. 2019 - 2023. Todos los derechos reservado

# ****************************************************************
# IDE:          PyCharm
# Developed by: macercha
# Date:         6/03/23 16:24
# Project:      CFHL Transactional Backend
# Module Name:  offer_state_machine
# Description:
# ****************************************************************
from datetime import timedelta
from django.utils import timezone
from django.db import DatabaseError
from django.utils.translation import gettext_lazy as _
from oasis.models import Operation
from oasis.models import StateMachine


class OfferStateMachine:
    def __init__(self, offer, operation):
        self.__offer = offer
        self.__operation = operation
        self.__from_status = offer.status

    def run(self) -> None:
        """
        Run a machine state to get and assign next state value.
        :return:
        """
        oasis_state = self.__operation.state
        oasis_status = self.__operation.status
        state = StateMachine.objects.get_next_state(from_state=self.__from_status, oasis_state=oasis_state,
                                                    oasis_status=oasis_status)
        if state is not None:
            self.__offer.status = state.state
            # Change kg received
            if self.__offer.kg_received != self.__operation.quantity:
                self.__offer.kg_received = self.__operation.quantity

            if state.is_changed:
                # Change kg offered
                if self.__offer.kg_offered != self.__operation.otherif:
                    self.__offer.kg_offered = self.__operation.otherif
                # Change delivery date
                if self.__offer.delivery_date != self.__operation.finaldate:
                    self.__offer.delivery_date = self.__operation.finaldate

            self.__offer.save()

    def set(self, new_state: int) -> None:
        """
        Set a new state and assign state and status in oasis operation entity
        :param new_state: new state value
        :return:
        """
        state = StateMachine.objects.get_next_oasis_status(from_state=self.__offer.status, new_state=new_state)

        if state is not None:
            if Operation.objects.update_status(location_id=self.__operation.locationid,
                                               document_id=self.__operation.documentid,
                                               number_id=self.__operation.numberid, state=state.oasis_state,
                                               status=state.oasis_status):
                self.__offer.status = new_state
                self.__offer.save()
            else:
                raise DatabaseError(_("Error updating operation record"))

    def validate_timeout(self) -> None:
        """
        Validate a state timeout and set a new state.
        :return:
        """
        now = timezone.now()
        state = StateMachine.objects.get_current_state(current_state=self.__offer.status, oasis_state=self.__operation.state, oasis_status=self.__operation.status)
        if state is not None and state.timeout > 0:
            if (now - self.__offer.modified_at) > timedelta(hours=state.timeout):
                self.set(state.state_at_timeout)




# -*- coding: utf-8 -*-

#  Developed by CQ Inversiones SAS. Copyright ©. 2019 - 2023. All rights reserved.
#  Desarrollado por CQ Inversiones SAS. Copyright ©. 2019 - 2023. Todos los derechos reservado

# ****************************************************************
# IDE:          PyCharm
# Developed by: macercha
# Date:         26/02/23 15:31
# Project:      CFHL Transactional Backend
# Module Name:  oasis_states
# Description:
# ****************************************************************
from django.utils.translation import gettext_lazy as _
from zibanu.django.db import models


class OasisStates(models.TextChoices):
    ACTIVE = "A", _("Active")
    PROCESSED = "P", _("Processed")
    CANCELED = "X", _("Canceled")



# -*- coding: utf-8 -*-

#  Developed by CQ Inversiones SAS. Copyright ©. 2019 - 2022. All rights reserved.
#  Desarrollado por CQ Inversiones SAS. Copyright ©. 2019 - 2022. Todos los derechos reservado

# ****************************************************************
# IDE:          PyCharm
# Developed by: macercha
# Date:         16/11/22 2:39 PM
# Project:      CFHL Transactional Backend
# Module Name:  __init__.py
# Description:
# ****************************************************************
from .local_coffee_ware_house import CoffeeWareHouse
from .local_company import Company
from .local_document_type import DocumentType
from .local_offer import Offer
from .local_product import Product
from .local_state_machine import StateMachine
from .oasis_associate_balance import AssociateBalance
from .oasis_client import OasisClient
from .oasis_company import OasisCompany
from .oasis_cycle import Cycle
from .oasis_discount import OasisDiscount
from .oasis_geographic_location import OasisGeographicLocation
from .oasis_location import OasisLocation
from .oasis_operation import Operation
from .oasis_periods import Periods
from .oasis_product import OasisProduct
from .oasis_type_client import OasisTypeClient


__all__ = [
    "AssociateBalance",
    "CoffeeWareHouse",
    "Company",
    "Cycle",
    "DocumentType",
    "OasisClient",
    "OasisCompany",
    "OasisDiscount",
    "OasisGeographicLocation",
    "OasisLocation",
    "OasisProduct",
    "OasisTypeClient",
    "Product",
    "StateMachine"
]



# -*- coding: utf-8 -*-

#  Developed by CQ Inversiones SAS. Copyright ©. 2019 - 2023. All rights reserved.
#  Desarrollado por CQ Inversiones SAS. Copyright ©. 2019 - 2023. Todos los derechos reservado

# ****************************************************************
# IDE:          PyCharm
# Developed by: macercha
# Date:         28/01/23 9:36
# Project:      CFHL Transactional Backend
# Module Name:  local_company
# Description:
# ****************************************************************
from zibanu.django.db import models


class Company(models.Manager):
    def get_by_company_id(self, company_id: int):
        return self.filter(company_id__exact=company_id)


# -*- coding: utf-8 -*-

#  Developed by CQ Inversiones SAS. Copyright ©. 2019 - 2022. All rights reserved.
#  Desarrollado por CQ Inversiones SAS. Copyright ©. 2019 - 2022. Todos los derechos reservado

# ****************************************************************
# IDE:          PyCharm
# Developed by: macercha
# Date:         10/12/22 3:51 PM
# Project:      CFHL Transactional Backend
# Module Name:  __init__.py
# Description:
# ****************************************************************
from .local_models import CoffeeWareHouse
from .local_models import Company
from .local_models import DocumentType
from .local_models import Offer
from .local_models import OfferMov
from .local_models import Product
from .local_models import StateMachine
from .oasis_models import Account
from .oasis_models import AssociateBalance
from .oasis_models import Classification
from .oasis_models import Client
from .oasis_models import Cycle
from .oasis_models import Discount
from .oasis_models import GeographicLocation
from .oasis_models import Location
from .oasis_models import OasisCompany
from .oasis_models import OasisProduct
from .oasis_models import Operation
from .oasis_models import Periods
from .oasis_models import TypeClient

__all__ = [
    "AssociateBalance",
    "Classification",
    "Client",
    "CoffeeWareHouse",
    "Company",
    "Cycle",
    "Discount",
    "DocumentType",
    "GeographicLocation",
    "Location",
    "Product",
    "OasisCompany",
    "OasisProduct",
    "Offer",
    "OfferMov",
    "Operation",
    "Periods",
    "StateMachine",
    "TypeClient"
]




# -*- coding: utf-8 -*-

#  Developed by CQ Inversiones SAS. Copyright ©. 2019 - 2022. All rights reserved.
#  Desarrollado por CQ Inversiones SAS. Copyright ©. 2019 - 2022. Todos los derechos reservado

# ****************************************************************
# IDE:          PyCharm
# Developed by: macercha
# Date:         20/12/22 6:10 AM
# Project:      CFHL Transactional Backend
# Module Name:  client
# Description:
# ****************************************************************
from django.core.exceptions import ValidationError
from django.core.validators import validate_email
from django.utils.translation import gettext_lazy as _
from oasis.lib.choices import CustomerType
from typing import Any
from zibanu.django.db import models


class OasisClient(models.Manager):
    """
    Default manager for Client model
    """

    def get_by_pk(self, pk: Any, customer_status: str = None) -> models.QuerySet:
        """
        Override a default class method
        :param pk: customer id for query
        :param customer_status: state of customer to validate
        :return: queryset with data
        """
        qs = self.get_queryset().filter(clientid__exact=pk)
        if customer_status is not None:
            qs = qs.filter(state__exact=customer_status)
        if len(qs) == 0:
            raise self.model.DoesNotExist(_("OASIS Error. The customer does not exists."))
        return qs

    def get_customer(self, customer_id: int, email: str) -> models.Model:
        """
        Get a Customer object with validations if email and document id are valid
        :param customer_id: customer id for search
        :param email: email to validate
        :return:
        """
        # Change email and set standard
        email = email.strip().lower()
        # Get customer from OASIS table
        qs = self.get_by_pk(pk=customer_id, customer_status="A")
        customer = qs.first()
        if ";" in customer.email:
            customer_email = customer.email.split(";")[0].strip().lower()
            customer.email = customer_email
        else:
            customer_email = customer.email.strip().lower()

        # Validate customer and set customer type.
        try:
            validate_email(customer_email)
            customer.is_valid = True if email == customer_email else False
            if customer.customer_type == 0:
                raise ValidationError(_("The customer does not belong to the company."))
        except self.model.DoesNotExist:
            customer.is_valid = False
        except ValidationError as exc:
            customer.is_valid = False
            raise ValidationError(exc) from exc

        return customer




# -*- coding: utf-8 -*-

#  Developed by CQ Inversiones SAS. Copyright ©. 2019 - 2023. All rights reserved.
#  Desarrollado por CQ Inversiones SAS. Copyright ©. 2019 - 2023. Todos los derechos reservado

# ****************************************************************
# IDE:          PyCharm
# Developed by: macercha
# Date:         17/01/23 6:22 AM
# Project:      CFHL Transactional Backend
# Module Name:  geographic_location
# Description:
# ****************************************************************
from django.utils.translation import gettext_lazy as _
from typing import Any
from zibanu.django.db import models


class OasisGeographicLocation(models.Manager):
    """
    GeographicLocation entity manager
    """
    def get_by_pk(self, pk: Any) -> models.QuerySet:
        """
        Method override for get_by_pk default method
        :param pk: fake pk for get location from it´s id
        :return: queryset if found, else raise DoesNotExists exception
        """
        qs = self.get_queryset().filter(geographiclocationid__exact=pk)
        if len(qs) == 0:
            self.model.DoesNotExist(_("The location does not exists."))
        return qs




# -*- coding: utf-8 -*-

#  Developed by CQ Inversiones SAS. Copyright ©. 2019 - 2023. All rights reserved.
#  Desarrollado por CQ Inversiones SAS. Copyright ©. 2019 - 2023. Todos los derechos reservado

# ****************************************************************
# IDE:          PyCharm
# Developed by: macercha
# Date:         8/03/23 9:01
# Project:      CFHL Transactional Backend
# Module Name:  local_state_machine
# Description:
# ****************************************************************
from typing import Any
from zibanu.django.db import models


class StateMachine(models.Manager):
    def get_next_state(self, from_state: int, oasis_state: str, oasis_status: str) -> models.Model:
        """
        Method to get next state value based on current states.
        :param from_state: from what state start search
        :param oasis_state: oasis current state
        :param oasis_status: oasis current status
        :return: state record
        """
        state = self.filter(from_state__exact=from_state, oasis_state__exact=oasis_state,
                            oasis_status__exact=oasis_status, update_oasis__exact=False).first()
        return state

    def get_next_oasis_status(self, from_state: int, new_state: int) -> models.Model:
        """
        Get next oasis status for set a new offer status
        :param from_state: from start state search
        :param new_state: new state to set
        :return: state record
        """
        state = self.filter(from_state__exact=from_state, state__exact=new_state, update_oasis__exact=True).first()
        return state

    def get_current_state(self, current_state: int, oasis_state: str, oasis_status: str) -> models.Model:
        """
        Get current state record
        :param current_state: current offer state
        :param oasis_state: current oasis operation state
        :param oasis_status: current oasis operation status
        :return: state record
        """
        state = self.filter(state__exact=current_state, oasis_state__exact=oasis_state,
                            oasis_status__exact=oasis_status).first()
        return state



# -*- coding: utf-8 -*-

#  Developed by CQ Inversiones SAS. Copyright ©. 2019 - 2023. All rights reserved.
#  Desarrollado por CQ Inversiones SAS. Copyright ©. 2019 - 2023. Todos los derechos reservado

# ****************************************************************
# IDE:          PyCharm
# Developed by: macercha
# Date:         22/02/23 9:18
# Project:      CFHL Transactional Backend
# Module Name:  apps
# Description:
# ****************************************************************
from django.apps import AppConfig
from django.conf import settings
from django.utils.translation import gettext_lazy as _


class OasisCoffeeOffer(AppConfig):
    default_auto_field = "django.db.models.BigAutoField"
    name = "oasis.coffee_offers"
    label = "coffee_offer"
    verbose_name = _("Oasis4 Coffee Offer ")

    def ready(self):
        """
        Method loaded on ready event pre_load application
        :return: None
        """
        # Import events for signals
        import oasis.coffee_offers.lib.events
        # Document ID to save Coffee Offer
        settings.COFFEE_OFFERS_DOCUMENT = getattr(settings, "COFFEE_OFFERS_DOCUMENT", "OA")
        # Concept ID to save Coffee Offer
        settings.COFFEE_OFFERS_CONCEPT = getattr(settings, "COFFEE_OFFERS_CONCEPT", "CF")
        # Discount ID to save Coffee Offer
        settings.COFFEE_OFFERS_DISCOUNT = getattr(settings, "COFFEE_OFFERS_DISCOUNT", 26)
        # Motive ID to save Coffee Offer
        settings.COFFEE_OFFERS_MOTIVE = getattr(settings, "COFFEE_OFFERS_MOTIVE", 9)
        # Max Active Offers
        settings.COFFEE_OFFERS_MAX_ACTIVE = getattr(settings, "COFFEE_OFFERS_MAX_ACTIVE", 3)
        # Set of status values for validators
        settings.COFFEE_OFFERS_STATUSES = getattr(settings, "COFFEE_OFFERS_STATUSES", "DPRTX")
        # Delta days for validate delivery dato of coffee offer
        settings.COFFEE_OFFERS_DAYS_DELTA = getattr(settings, "COFFEE_OFFERS_DAYS_DELTA", 15)
        # Segment excluded of coffee offers
        settings.COFFEE_OFFERS_LOCKED_SEGMENT = getattr(settings, "COFFEE_OFFERS_LOCKED_SEGMENT", 0)
        # Merchant segment for coffee offers
        settings.COFFEE_OFFERS_TRADER_SEGMENT = getattr(settings, "COFFEE_OFFERS_TRADER_SEGMENT", 77)
        # Merchants quota in KG
        settings.COFFEE_OFFERS_TRADER_QUOTA = getattr(settings, "COFFEE_OFFERS_TRADER_QUOTA", 30000)
        # Default quota in KG
        settings.COFFEE_OFFERS_DEFAULT_QUOTA = getattr(settings, "COFFEE_OFFERS_DEFAULT_QUOTA", 3000)
        # Calculate quota discounting active offers
        settings.COFFEE_OFFERS_CALCULATE_QUOTA = getattr(settings, "COFFEE_OFFERS_CALCULATE_QUOTA", False)
        # Delta price for minor or major value
        settings.COFFEE_OFFERS_PRICE_DELTA = getattr(settings, "COFFEE_OFFERS_PRICE_DELTA", 10)
        # Show all offers or only active
        settings.COFFEE_OFFERS_LOAD_ALL = getattr(settings, "COFFEE_OFFERS_LOAD_ALL", False)
        # Round factor
        settings.COFFEE_OFFERS_ROUND_FACTOR = getattr(settings, "COFFEE_OFFERS_ROUND_FACTOR", 10)
        # Contract Template
        settings.COFFEE_OFFERS_CONTRACT_TEMPLATE = getattr(settings, "COFFEE_OFFERS_CONTRACT_TEMPLATE",
                                                           "contract_template.html")
        # Terms and conditions template
        settings.COFFEE_OFFERS_TERMS_TEMPLATE = getattr(settings, "COFFEE_OFFERS_TERMS_TEMPLATE",
                                                        "terms_conditions.html")
        # Promissory note
        settings.COFFEE_OFFERS_PROMISE_TEMPLATE = getattr(settings, "COFFEE_OFFERS_PROMISE_TEMPLATE",
                                                          "promisory_note.html")
        # Coffee factor for offers
        settings.COFFEE_OFFERS_FACTOR = getattr(settings, "COFFEE_OFFERS_FACTOR", 94)
        # Coffee Offers product list
        settings.COFFEE_OFFERS_PRODUCT_LIST = getattr(settings, "COFFEE_OFFERS_PRODUCT_LIST",
                                                      "2101,2102,2104,2106,2107,2109,2112,2113,2114,2126,2120,2134")



# -*- coding: utf-8 -*-

#  Developed by CQ Inversiones SAS. Copyright ©. 2019 - 2023. All rights reserved.
#  Desarrollado por CQ Inversiones SAS. Copyright ©. 2019 - 2023. Todos los derechos reservado

# ****************************************************************
# IDE:          PyCharm
# Developed by: macercha
# Date:         26/02/23 15:26
# Project:      CFHL Transactional Backend
# Module Name:  coffee_offers_states
# Description:
# ****************************************************************
from django.utils.translation import gettext_lazy as _
from zibanu.django.db import models


class CoffeeOffersStates(models.IntegerChoices):
    NEW = 0, _("New")
    CHANGED = 1, _("Changed")
    SIGNED = 2, _("Signed")
    PARTIAL = 3, _("Partial")
    FINISHED = 4, _("Finished")
    REJECTED = 9, _("Rejected")

    @classmethod
    def active_list(cls) -> list:
        return [cls.SIGNED, cls.PARTIAL]

    @classmethod
    def ended_list(cls) -> list:
        return [cls.FINISHED, cls.REJECTED]

    @classmethod
    def not_ended_list(cls) -> list:
        return [cls.NEW, cls.CHANGED, cls.SIGNED, cls.PARTIAL]
